@@ -2,7 +2,7 @@
 //
 // exceptions.h: Rcpp R/C++ interface class library -- exceptions
 //
-// Copyright (C) 2010	Dirk Eddelbuettel and Romain Francois
+// Copyright (C) 2010 - 2011 Dirk Eddelbuettel and Romain Francois
 //
 // This file is part of Rcpp.
 //
@@ -50,6 +50,28 @@ private:
     std::string message ;                                                      
 } ;
 
+class file_io_error : public std::exception {                                      
+public:                                                                        
+    file_io_error(const std::string& file) throw() : message( std::string("file io error: '") + file + "'" ), file(file) {} ;
+    file_io_error(int code, const std::string& file) throw() : message( "file io error " + toString(code) + ": '" + file + "'"), file(file) {} ;
+    file_io_error(const std::string& msg, const std::string& file) throw() : message( msg + ": '" + file + "'"), file(file) {} ;
+    virtual ~file_io_error() throw(){} ;                                         
+    virtual const char* what() const throw(){ return message.c_str() ; } ; 
+    std::string filePath() const throw(){ return file ; } ;
+private:                                                                       
+    std::string message ;                                                      
+    std::string file;
+} ;
+
+class file_not_found : public file_io_error {
+public:
+    file_not_found(const std::string& file) throw() : file_io_error("file not found", file) {}
+};
+
+class file_exists : public file_io_error {
+public:
+    file_exists(const std::string& file) throw() : file_io_error("file already exists", file) {}
+};
 
 #define RCPP_EXCEPTION_CLASS(__CLASS__,__WHAT__)                               \
 class __CLASS__ : public std::exception{                                       \
@@ -74,6 +96,7 @@ RCPP_SIMPLE_EXCEPTION_CLASS(index_out_of_bounds, "index out of bounds")
 RCPP_SIMPLE_EXCEPTION_CLASS(parse_error, "parse error") 
 RCPP_SIMPLE_EXCEPTION_CLASS(not_s4, "not an S4 object")
 RCPP_SIMPLE_EXCEPTION_CLASS(not_reference, "not an S4 object of a reference class")
+RCPP_SIMPLE_EXCEPTION_CLASS(not_initialized, "C++ object not initialized (missing default constructor?)")
 RCPP_SIMPLE_EXCEPTION_CLASS(no_such_slot, "no such slot")
 RCPP_SIMPLE_EXCEPTION_CLASS(no_such_field, "no such field")
 RCPP_SIMPLE_EXCEPTION_CLASS(not_a_closure, "not a closure")
@@ -87,6 +110,7 @@ RCPP_EXCEPTION_CLASS(no_such_binding, std::string("no such binding : '") + messa
 RCPP_EXCEPTION_CLASS(binding_not_found, std::string("binding not found: '") + message + "'" )
 RCPP_EXCEPTION_CLASS(binding_is_locked, std::string("binding is locked: '") + message + "'" )
 RCPP_EXCEPTION_CLASS(no_such_namespace, std::string("no such namespace: '") + message + "'" )
+RCPP_EXCEPTION_CLASS(function_not_exported, std::string("function not exported: ") + message)
 RCPP_EXCEPTION_CLASS(eval_error, message )
 
 #undef RCPP_EXCEPTION_CLASS
