@@ -2,7 +2,7 @@
 //
 // times.h: Rcpp R/C++ interface class library -- operator*
 //                                                                      
-// Copyright (C) 2010	Dirk Eddelbuettel and Romain Francois
+// Copyright (C) 2010 - 2011 Dirk Eddelbuettel and Romain Francois
 //
 // This file is part of Rcpp.
 //
@@ -51,7 +51,33 @@ namespace sugar{
 	private:
 		const LHS_EXT& lhs ;
 		const RHS_EXT& rhs ;
-	} ;	
+	} ;
+    // RTYPE = REALSXP
+    template <bool LHS_NA, typename LHS_T, bool RHS_NA, typename RHS_T >
+	class Times_Vector_Vector<REALSXP,LHS_NA,LHS_T,RHS_NA,RHS_T> : 
+	    public Rcpp::VectorBase<REALSXP, true , Times_Vector_Vector<REALSXP,LHS_NA,LHS_T,RHS_NA,RHS_T> > {
+	public:
+		typedef typename Rcpp::VectorBase<REALSXP,LHS_NA,LHS_T> LHS_TYPE ;
+		typedef typename Rcpp::VectorBase<REALSXP,RHS_NA,RHS_T> RHS_TYPE ;
+		
+		typedef typename Rcpp::traits::Extractor<REALSXP, LHS_NA, LHS_T>::type LHS_EXT ;
+		typedef typename Rcpp::traits::Extractor<REALSXP, RHS_NA, RHS_T>::type RHS_EXT ;
+		
+		Times_Vector_Vector( const LHS_TYPE& lhs_, const RHS_TYPE& rhs_ ) : 
+			lhs(lhs_.get_ref()), rhs(rhs_.get_ref()) {
+		}
+		
+		inline double operator[]( int i ) const {
+			return lhs[i] * rhs[i];
+		}
+		
+		inline int size() const { return lhs.size() ; }
+		
+	private:
+		const LHS_EXT& lhs ;
+		const RHS_EXT& rhs ;
+	} ;
+    	
 	
 	// specialization LHS_NA = false
 	template <int RTYPE, typename LHS_T, bool RHS_NA, typename RHS_T >
@@ -78,7 +104,32 @@ namespace sugar{
 	private:
 		const LHS_EXT& lhs ;
 		const RHS_EXT& rhs ;
-	} ;	
+	} ;
+	// RTYPE = REALSXP
+	template <typename LHS_T, bool RHS_NA, typename RHS_T >
+	class Times_Vector_Vector<REALSXP,false,LHS_T,RHS_NA,RHS_T> : 
+	    public Rcpp::VectorBase<REALSXP,true, Times_Vector_Vector<REALSXP,false,LHS_T,RHS_NA,RHS_T> > {
+	public:
+		typedef typename Rcpp::VectorBase<REALSXP,false,LHS_T> LHS_TYPE ;
+		typedef typename Rcpp::VectorBase<REALSXP,RHS_NA,RHS_T> RHS_TYPE ;
+		
+		typedef typename Rcpp::traits::Extractor<REALSXP, false, LHS_T>::type LHS_EXT ;
+		typedef typename Rcpp::traits::Extractor<REALSXP, RHS_NA, RHS_T>::type RHS_EXT ;
+		
+		Times_Vector_Vector( const LHS_TYPE& lhs_, const RHS_TYPE& rhs_ ) : 
+			lhs(lhs_.get_ref()), rhs(rhs_.get_ref()){}
+		
+		inline double operator[]( int i ) const {
+			return lhs[i] * rhs[i] ;
+		}
+		
+		inline int size() const { return lhs.size() ; }
+		
+	private:
+		const LHS_EXT& lhs ;
+		const RHS_EXT& rhs ;
+	} ;
+	
 
 	// specialization for RHS_NA = false 
 	template <int RTYPE, bool LHS_NA, typename LHS_T, typename RHS_T >
@@ -102,12 +153,35 @@ namespace sugar{
 		
 		inline int size() const { return lhs.size() ; }
 		
+	private:
+		const LHS_EXT& lhs ;
+		const RHS_EXT& rhs ;
+	} ;
+	// RTYPE = REALSXP
+	template <bool LHS_NA, typename LHS_T, typename RHS_T >
+	class Times_Vector_Vector<REALSXP,LHS_NA,LHS_T,false,RHS_T> : 
+	    public Rcpp::VectorBase<REALSXP, true , Times_Vector_Vector<REALSXP,LHS_NA,LHS_T,false,RHS_T> > {
+	public:
+		typedef typename Rcpp::VectorBase<REALSXP,LHS_NA,LHS_T> LHS_TYPE ;
+		typedef typename Rcpp::VectorBase<REALSXP,false,RHS_T> RHS_TYPE ;
+		
+		typedef typename Rcpp::traits::Extractor<REALSXP, LHS_NA, LHS_T>::type LHS_EXT ;
+		typedef typename Rcpp::traits::Extractor<REALSXP, false, RHS_T>::type RHS_EXT ;
+		
+		Times_Vector_Vector( const LHS_TYPE& lhs_, const RHS_TYPE& rhs_ ) : 
+			lhs(lhs_.get_ref()), rhs(rhs_.get_ref()){}
+		
+		inline double operator[]( int i ) const {
+			return lhs[i] * rhs[i] ;
+		}
+		
+		inline int size() const { return lhs.size() ; }
+		
 	private:
 		const LHS_EXT& lhs ;
 		const RHS_EXT& rhs ;
 	} ;	
 
-
 	// specialization for RHS_NA = false  and LHS_NA = false 
 	template <int RTYPE, typename LHS_T, typename RHS_T >
 	class Times_Vector_Vector<RTYPE,false,LHS_T,false,RHS_T> : public Rcpp::VectorBase<RTYPE, false , Times_Vector_Vector<RTYPE,false,LHS_T,false,RHS_T> > {
@@ -132,8 +206,31 @@ namespace sugar{
 		const LHS_EXT& lhs ;
 		const RHS_EXT& rhs ;
 	} ;	
-	
-	
+    // RTYPE = REALSXP	
+	template <typename LHS_T, typename RHS_T >
+	class Times_Vector_Vector<REALSXP,false,LHS_T,false,RHS_T> : 
+	    public Rcpp::VectorBase<REALSXP, false , Times_Vector_Vector<REALSXP,false,LHS_T,false,RHS_T> > {
+	public:
+		typedef typename Rcpp::VectorBase<REALSXP,false,LHS_T> LHS_TYPE ;
+		typedef typename Rcpp::VectorBase<REALSXP,false,RHS_T> RHS_TYPE ;
+		
+		typedef typename Rcpp::traits::Extractor<REALSXP, false, LHS_T>::type LHS_EXT ;
+		typedef typename Rcpp::traits::Extractor<REALSXP, false, RHS_T>::type RHS_EXT ;
+		                                                     
+		Times_Vector_Vector( const LHS_TYPE& lhs_, const RHS_TYPE& rhs_ ) : 
+			lhs(lhs_.get_ref()), rhs(rhs_.get_ref()){}
+		
+		inline double operator[]( int i ) const {
+			return lhs[i] * rhs[i]  ;
+		}
+		
+		inline int size() const { return lhs.size() ; }
+		
+	private:
+		const LHS_EXT& lhs ;
+		const RHS_EXT& rhs ;
+	} ;	
+
 	
 	template <int RTYPE, bool NA, typename T>
 	class Times_Vector_Primitive : public Rcpp::VectorBase<RTYPE,true, Times_Vector_Primitive<RTYPE,NA,T> > {
@@ -159,7 +256,28 @@ namespace sugar{
 		const EXT& lhs ;
 		STORAGE rhs ;
 		bool rhs_na ;
+	} ;
+	// RTYPE = REALSXP
+	template <bool NA, typename T>
+	class Times_Vector_Primitive<REALSXP,NA,T> : 
+	    public Rcpp::VectorBase<REALSXP,true, Times_Vector_Primitive<REALSXP,NA,T> > {
+	public:
+		typedef typename Rcpp::VectorBase<REALSXP,NA,T> VEC_TYPE ;
+		typedef typename Rcpp::traits::Extractor<REALSXP, NA, T>::type EXT ;
 		
+		Times_Vector_Primitive( const VEC_TYPE& lhs_, double rhs_ ) : 
+			lhs(lhs_.get_ref()), rhs(rhs_)
+			{}
+		
+		inline double operator[]( int i ) const {
+			return rhs * lhs[i] ;
+		}
+		
+		inline int size() const { return lhs.size() ; }
+		
+	private:
+		const EXT& lhs ;
+		double rhs ;
 	} ;
 	
 	
@@ -186,6 +304,27 @@ namespace sugar{
 		bool rhs_na ;
 		
 	} ;
+	// RTYPE = REALSXP
+	template <typename T>
+	class Times_Vector_Primitive<REALSXP,false,T> : 
+	    public Rcpp::VectorBase<REALSXP,false, Times_Vector_Primitive<REALSXP,false,T> > {
+	public:
+		typedef typename Rcpp::VectorBase<REALSXP,false,T> VEC_TYPE ;
+		typedef typename Rcpp::traits::Extractor<REALSXP, false, T>::type EXT ;
+		
+		Times_Vector_Primitive( const VEC_TYPE& lhs_, double rhs_ ) : 
+			lhs(lhs_.get_ref()), rhs(rhs_) {}
+		
+		inline double operator[]( int i ) const {
+			return rhs * lhs[i] ;
+		}
+		
+		inline int size() const { return lhs.size() ; }
+		
+	private:
+		const EXT& lhs ;
+		double rhs ;
+	} ;
 	
 
 
@@ -193,7 +332,6 @@ namespace sugar{
 	
 	
 	// Vector * nona(primitive)
-	
 	template <int RTYPE, bool NA, typename T>
 	class Times_Vector_Primitive_nona : public Rcpp::VectorBase<RTYPE,true, Times_Vector_Primitive_nona<RTYPE,NA,T> > {
 	public:
@@ -217,6 +355,28 @@ namespace sugar{
 		STORAGE rhs ;
 		
 	} ;
+	// RTYPE = REALSXP
+	template <bool NA, typename T>
+	class Times_Vector_Primitive_nona<REALSXP,NA,T> : 
+	    public Rcpp::VectorBase<REALSXP,true, Times_Vector_Primitive_nona<REALSXP,NA,T> > {
+	public:
+		typedef typename Rcpp::VectorBase<REALSXP,NA,T> VEC_TYPE ;
+		typedef typename Rcpp::traits::Extractor<REALSXP,NA,T>::type EXT ;
+		   
+		Times_Vector_Primitive_nona( const VEC_TYPE& lhs_, double rhs_ ) : 
+			lhs(lhs_.get_ref()), rhs(rhs_)
+			{}
+		
+		inline double operator[]( int i ) const {
+			return lhs[i] * rhs ;
+		}
+		
+		inline int size() const { return lhs.size() ; }
+		
+	private:
+		const EXT& lhs ;
+		double rhs ;
+	} ;
 
 	
 	template <int RTYPE, typename T>
@@ -241,6 +401,26 @@ namespace sugar{
 		STORAGE rhs ;
 		
 	} ;
+	template <typename T>
+	class Times_Vector_Primitive_nona<REALSXP,false,T> : 
+	    public Rcpp::VectorBase<REALSXP,false, Times_Vector_Primitive_nona<REALSXP,false,T> > {
+	public:
+		typedef typename Rcpp::VectorBase<REALSXP,false,T> VEC_TYPE ;
+		typedef typename Rcpp::traits::Extractor<REALSXP, false, T>::type EXT ;
+		
+		Times_Vector_Primitive_nona( const VEC_TYPE& lhs_, double rhs_ ) : 
+			lhs(lhs_.get_ref()), rhs(rhs_) {}
+		         
+		inline double operator[]( int i ) const {
+			return rhs * lhs[i] ;
+		}
+		
+		inline int size() const { return lhs.size() ; }
+		
+	private:
+		const EXT& lhs ;
+		double rhs ;
+	} ;
 	
 }
 }
