@@ -1,7 +1,7 @@
 #!/usr/bin/r -t
-# -*- mode: R; tab-width: 4 -*-
+# -*- mode: R; tab-width: 4; -*-
 #
-# Copyright (C) 2010, 2012   Dirk Eddelbuettel and Romain Francois
+# Copyright (C) 2010 - 2012   Dirk Eddelbuettel and Romain Francois
 #
 # This file is part of Rcpp.
 #
@@ -18,6 +18,10 @@
 # You should have received a copy of the GNU General Public License
 # along with Rcpp.  If not, see <http://www.gnu.org/licenses/>.
 
+.runThisTest <- Sys.getenv("RunAllRcppTests") == "yes"
+
+if (.runThisTest) {
+
 definitions <- function() {
     list(          "ctor_sexp"=list(
                    signature(d="Date"),
@@ -305,3 +309,5 @@ test.DatetimeVector.ctor <- function() {
     posixtNA <- as.POSIXct(NA,  origin="1970-01-01")
     checkEquals(fun(vec), c(now, rep(posixtNA, 3), now+2.345), msg = "Datetime.ctor.set")
 }
+
+}
