@@ -1,6 +1,7 @@
 #!/usr/bin/r -t
+#       hey emacs, please make this use  -*- tab-width: 4 -*-
 #
-# Copyright (C) 2010	Dirk Eddelbuettel and Romain Francois
+# Copyright (C) 2010 - 2012  Dirk Eddelbuettel and Romain Francois
 #
 # This file is part of Rcpp.
 #
@@ -17,74 +18,86 @@
 # You should have received a copy of the GNU General Public License
 # along with Rcpp.  If not, see <http://www.gnu.org/licenses/>.
 
+.runThisTest <- Sys.getenv("RunAllRcppTests") == "yes"
+
+if (.runThisTest) {
+
 definitions <- function(){
     f <- list(
-        	"raw_" = list( 
-        		signature(), 
+              "raw_" = list(
+        		signature(),
         		'
 				RawVector x(10) ;
 				for( int i=0; i<10; i++) x[i] = (Rbyte)i ;
 				return x ;
 				'
-        	), 
-        	"raw_REALSXP" = list( 
+              ),
+
+              "raw_REALSXP" = list(
         		signature(vec = "raw" ),
         		'
 				RawVector x(vec) ;
-				for( int i=0; i<x.size(); i++) { 
+				for( int i=0; i<x.size(); i++) {
 					x[i] = x[i]*2 ;
 				}
 				return x ;
 				'
-        	), 
-        	"expression_" = list( 
-        		signature(), 
+              ),
+
+              "expression_" = list(
+        		signature(),
         		'
 				ExpressionVector x(2) ;
 				x[0] = Symbol( "rnorm" ) ;
 				x[1] = Rf_lcons( Symbol("rnorm"), Rf_cons( Rf_ScalarReal(10.0), R_NilValue) ) ;
 				return x ;
 				'
-        	), 
-        	"expression_variadic" = list( 
-        		signature(), 
+              ),
+
+              "expression_variadic" = list(
+        		signature(),
         		'
 				ExpressionVector x(2) ;
 				x[0] = Symbol( "rnorm" ) ;
 				x[1] = Language( "rnorm", 10.0 ) ;
 				return x ;
 				'
-        	), 
-        	"expression_parse" = list( 
-        		signature(), 
+              ),
+
+        	  "expression_parse" = list(
+        		signature(),
         		'
-					ExpressionVector code( "local( { y <- sample(1:10); sort(y) })" ) ;
-					return code ;
+				ExpressionVector code( "local( { y <- sample(1:10); sort(y) })" ) ;
+				return code ;
 				'
-        	), 
-        	"expression_parseerror" = list( 
-        		signature(), 
+        	  ),
+
+        	  "expression_parseerror" = list(
+        		signature(),
         		'
-					ExpressionVector code( "rnorm(" ) ;
-					return code ;
+				ExpressionVector code( "rnorm(" ) ;
+				return code ;
 				'
-        	), 
-        	"expression_eval" = list( 
-        		signature(), 
+        	  ),
+
+              "expression_eval" = list(
+        		signature(),
         		'
 				ExpressionVector code( "local( { y <- sample(1:10); sort(y) })" ) ;
 				return code.eval() ;
 				'
-        	), 
-        	"expression_evalenv" = list( 
-        		signature(env = "environment"), 
+        	  ),
+
+              "expression_evalenv" = list(
+        		signature(env = "environment"),
         		'
 				ExpressionVector code( "sort(x)" ) ;
 				return code.eval(env) ;
-				' 
-        	), 
-        	"complex_" = list( 
-        		signature(), 
+				'
+              ),
+
+        	  "complex_" = list(
+        		signature(),
         		'
 				ComplexVector x(10) ;
 				Rcomplex rc ;
@@ -94,165 +107,188 @@ definitions <- function(){
 				}
 				return x ;
 				'
-        	), 
-        	"complex_CPLXSXP" = list( 
-        		signature(vec = "complex" ), 
+        	  ),
+
+        	  "complex_CPLXSXP" = list(
+        		signature(vec = "complex" ),
         		'
 				ComplexVector x(vec) ;
-                int nn = x.size();
-				for( int i=0; i<nn; i++) { 
+                		int nn = x.size();
+				for( int i=0; i<nn; i++) {
 					x[i].r = x[i].r*2 ;
 					x[i].i = x[i].i*2 ;
 				}
 				return x ;
 				'
-        	), 
-        	"complex_INTSXP" = list( 
-        		signature(vec = "integer" ), 
-        		'
-				ComplexVector x(vec);
-                int nn = x.size();
-                IntegerVector tmp(nn, 2.0);
-                ComplexVector tmp1(tmp);
-                x = x * tmp1;
-				return x ;
-				'
-        	), 
-        	"complex_REALSXP" = list( 
-        		signature(vec = "numeric" ), 
-        		'
-				ComplexVector x(vec);
-                int nn = x.size();
-                NumericVector tmp(nn, 3.0);
-                ComplexVector tmp1(tmp);
-                x = x * tmp1;
-				return x ;
-				'
-        	), 
-        	
-        	"integer_ctor"=list(
-                  signature(),
-                  'IntegerVector x(10) ;
-	           for( int i=0; i<10; i++) x[i] = i ;
-	           return x ;')
+        	  ),
 
-                  ,"integer_INTSXP_"=list(
+              "complex_INTSXP" = list(
+        		signature(vec = "integer" ),
+        		'
+				ComplexVector x(vec);
+	                	int nn = x.size();
+        	        	IntegerVector tmp(nn, 2.0);
+                		ComplexVector tmp1(tmp);
+                		x = x * tmp1;
+				return x ;
+			    '
+        	  ),
+
+              "complex_REALSXP" = list(
+        		signature(vec = "numeric" ),
+        		'
+					ComplexVector x(vec);
+                	int nn = x.size();
+                	NumericVector tmp(nn, 3.0);
+                	ComplexVector tmp1(tmp);
+                	x = x * tmp1;
+					return x ;
+				'
+        	  ),
+
+              "integer_ctor"=list(
+                  	signature(),
+                  	'IntegerVector x(10) ;
+	           	for( int i=0; i<10; i++) x[i] = i ;
+	           	return x ;'
+                ),
+
+              "integer_INTSXP_"=list(
                    signature(vec = "integer" ),
                    'IntegerVector x(vec) ;
 	            for( int i=0; i<x.size(); i++) {
-		       x[i] = x[i]*2 ;
+		          x[i] = x[i]*2 ;
 	            }
-	            return x ;')
+	            return x ;'
+              ),
 
-                  ,"integer_dimension_ctor_1"=list(
+              "integer_dimension_ctor_1"=list(
                    signature(),
-                   'return IntegerVector( Dimension( 5 ) ) ;')
+                   'return IntegerVector( Dimension( 5 ) ) ;'
+              ),
 
-                  ,"integer_dimension_ctor_2"=list(
+              "integer_dimension_ctor_2"=list(
                    signature(),
-                   'return IntegerVector( Dimension( 5, 5 ) ) ;')
+                   'return IntegerVector( Dimension( 5, 5 ) ) ;'
+              ),
 
-                  ,"integer_dimension_ctor_3"=list(
+              "integer_dimension_ctor_3"=list(
                    signature(),
-                   'return IntegerVector( Dimension( 2, 3, 4) ) ;')
+                   'return IntegerVector( Dimension( 2, 3, 4) ) ;'
+              ),
 
-                  ,"integer_range_ctor_1"=list(
+              "integer_range_ctor_1"=list(
                    signature(),
                    'int x[] = { 0, 1, 2, 3 } ;
-		    IntegerVector y( x, x+4 ) ;
-		    return y; ')
+		    		IntegerVector y( x, x+4 ) ;
+		    		return y; '
+              ),
 
-                  ,"integer_range_ctor_2"=list(
+              "integer_range_ctor_2"=list(
                    signature(),
                    'std::vector<int> vec(4) ;
-		    for( size_t i = 0; i<4; i++) vec[i] = i;
-		    IntegerVector y( vec.begin(), vec.end() ) ;
-		    return y;')
+		    		for( size_t i = 0; i<4; i++) vec[i] = i;
+		    		IntegerVector y( vec.begin(), vec.end() ) ;
+		    		return y;'
+              ),
 
-                  ,"integer_names_set"=list(
+              "integer_names_set"=list(
                    signature(),
                    'IntegerVector y(2) ;
-		    std::vector<std::string> names(2)  ;
-		    names[0] = "foo" ;
-		    names[1] = "bar" ;
-		    y.names() = names ;
-		    return y ; ')
+				    std::vector<std::string> names(2)  ;
+				    names[0] = "foo" ;
+				    names[1] = "bar" ;
+				    y.names() = names ;
+				    return y ; '
+              ),
 
-                  ,"integer_names_get"=list(
+              "integer_names_get"=list(
                    signature(x = "integer"),
                    'IntegerVector y(x) ;
-		    return y.names() ;')
+				    return y.names() ;'
+              ),
 
-                  ,"integer_names_indexing"=list(
+              "integer_names_indexing"=list(
                    signature(x = "integer"),
                    'IntegerVector y(x) ;
-		    return wrap( y["foo"] ); ')
+				    return wrap( y["foo"] ); '
+              ),
 
-                  ,"integer_comma"=list(
+              "integer_comma"=list(
                    signature(),
                    'IntegerVector x(4) ;
-	            x = 0, 1, 2, 3 ;
-	            return x ;')
+		            x = 0, 1, 2, 3 ;
+		            return x ;'
+              ),
 
-                  ,"integer_push_back"=list(
+              "integer_push_back"=list(
                    signature(x = "integer"),
                    'IntegerVector y(x) ;
 	            y.push_back( 5 ) ;
-	            return y ;')
+	            return y ;'
+                ),
 
-                  ,"integer_push_front"=list(
+              "integer_push_front"=list(
                    signature(x = "integer"),
                    'IntegerVector y(x) ;
 	            y.push_front( 5 ) ;
-	            return y ;')
+	            return y ;'
+                ),
 
-                  ,"integer_insert"=list(
+              "integer_insert"=list(
                    signature(x = "integer"),
                    'IntegerVector y(x) ;
 	            y.insert( 0, 5 ) ;
 	            y.insert( 2, 7 ) ;
-	            return y ;')
+	            return y ;'
+              ),
 
-                  ,"integer_erase"=list(
+              "integer_erase"=list(
                    signature(x = "integer"),
                    'IntegerVector y(x) ;
 	            y.erase(2) ;
-	            return y ;')
+	            return y ;'
+              ),
 
-                  ,"integer_erase2"=list(
+              "integer_erase2"=list(
                    signature(x = "integer"),
                    'IntegerVector y(x) ;
 	            y.erase(1,2) ;
-	            return y ;')
+	            return y ;'
+              ),
 
-                  ,"integer_fill"=list(
+              "integer_fill"=list(
                    signature(x = "integer"),
                    'IntegerVector y(x) ;
 	            y.fill(10) ;
-	            return y ;' )
+	            return y ;'
+              ),
 
-                  ,"integer_zero"=list(
+              "integer_zero"=list(
                    signature(),
-                   'return IntegerVector(0);' )
+                   'return IntegerVector(0);'
+              ),
 
-                  ,"integer_create_zero"=list(
+              "integer_create_zero"=list(
                    signature(),
                    'return IntegerVector::create();'
-                  ), 
-                  "integer_create_" = list( 
-                  signature(), 
-                  '
-					List output(2); 
+              ),
+
+              "integer_create_" = list(
+                	signature(),
+                  	'
+					List output(2);
 					output[0] = IntegerVector::create( 10, 20 ) ;
-					output[1] = IntegerVector::create( 
-						_["foo"] = 20, 
+					output[1] = IntegerVector::create(
+						_["foo"] = 20,
 						_["bar"] = 30 ) ;
 					return output ;
-					' 
-                  ), 
-                  "integer_clone_" = list( 
-                  signature(x="integer"), 
-                  '
+					'
+              ),
+
+              "integer_clone_" = list(
+                	  signature(x="integer"),
+                  	'
 					IntegerVector vec(x) ;
 					IntegerVector dolly = clone( vec ) ;
 					for( size_t i=0; i<10; i++){
@@ -260,418 +296,475 @@ definitions <- function(){
 					}
 					return dolly ;
 					'
-                  ) , 
-                  
-                  
-                  
-           "numeric_" = list( 
+              ),
+
+
+              "numeric_" = list(
         		signature(),
         		'
 				NumericVector x(10) ;
 				for( int i=0; i<10; i++) x[i] = i ;
 				return x ;
 				'
-        	), 
-        	"numeric_REALSXP" = list( 
-        		signature(vec = "numeric" ), 
+              ),
+
+              "numeric_REALSXP" = list(
+        		signature(vec = "numeric" ),
         		'
 				NumericVector x(vec) ;
-				for( int i=0; i<x.size(); i++) { 
+				for( int i=0; i<x.size(); i++) {
 					x[i] = x[i]*2.0 ;
 				}
 				return x ;
-				'	
-        	), 
-        	"numeric_import" = list( 
-        		signature(), 
+				'
+              ),
+
+              "numeric_import" = list(
+        		signature(),
         		'
 					std::vector<int> v(10) ;
 					for( int i=0; i<10; i++) v[i] = i ;
-					
+
 					return IntegerVector::import( v.begin(), v.end() ) ;
-				
+
 				'
-        	), 
-        	"numeric_importtransform" = list( 
-        		signature(), 
+              ),
+
+              "numeric_importtransform" = list(
+        		signature(),
         		'
 					std::vector<double> v(10) ;
 					for( int i=0; i<10; i++) v[i] = i ;
-					
-					return NumericVector::import_transform( v.begin(), v.end(), square ) ;
-				
-				'
-        	)  , 
-        	
-        	
-        	
-        	
-        	
-        	"list_ctor"=list(
-                  signature(),
-                  'List x(10) ;
-	           for( int i=0; i<10; i++) x[i] = Rf_ScalarInteger( i * 2)  ;
-	           return x ;')
 
-                  ,"list_template_"=list(
+					return NumericVector::import_transform( v.begin(), v.end(), square ) ;
+
+				'
+              ),
+
+              "list_ctor"=list(
+                	  signature(),
+                  	'List x(10) ;
+	           	for( int i=0; i<10; i++) x[i] = Rf_ScalarInteger( i * 2)  ;
+	           	return x ;'
+              ),
+
+              "list_template_"=list(
                    signature(),
                    'List x(4) ;
 	            x[0] = "foo"  ;
 	            x[1] = 10 ;
 	            x[2] = 10.2 ;
 	            x[3] = false;
-	            return x ;')
+	            return x ;'
+              ),
 
-                  ,"list_VECSXP_"=list(
+              "list_VECSXP_"=list(
                    signature(vec = "list" ),
                    'List x(vec) ;
-                    return x ;')
+                    return x ;'
+              ),
 
-                  ,"list_matrix_indexing_1"=list(
+              "list_matrix_indexing_1"=list(
                    signature(x = "character" ),
                    'GenericVector m(x) ;
-		    GenericVector out(4) ;
-		    for( size_t i=0 ; i<4; i++){
-		        out[i] = m(i,i) ;
-		    }
-		    return out ;')
+				    GenericVector out(4) ;
+				    for( size_t i=0 ; i<4; i++){
+				        out[i] = m(i,i) ;
+				    }
+				    return out ;'
+              ),
 
-                  ,"list_matrix_indexing_2"=list(
+              "list_matrix_indexing_2"=list(
                    signature(x = "integer" ),
                    'GenericVector m(x) ;
-		    for(size_t i=0 ; i<4; i++){
-		        m(i,i) = "foo" ;
-		    }
-		    return m ; ')
+				    for(size_t i=0 ; i<4; i++){
+				        m(i,i) = "foo" ;
+				    }
+				    return m ; '
+              ),
 
-                  ,"list_Dimension_constructor_1"=list(
+              "list_Dimension_constructor_1"=list(
                    signature(),
-                   'return List( Dimension( 5 ) ) ;')
+                   'return List( Dimension( 5 ) ) ;'
+              ),
 
-                  ,"list_Dimension_constructor_2"=list(
+              "list_Dimension_constructor_2"=list(
                    signature(),
-                   'return List( Dimension( 5, 5 ) );')
+                   'return List( Dimension( 5, 5 ) );'
+              ),
 
-                  ,"list_Dimension_constructor_3"=list(
+              "list_Dimension_constructor_3"=list(
                    signature(),
-                   ' return List( Dimension( 2, 3, 4) ) ;')
+                   ' return List( Dimension( 2, 3, 4) ) ;'
+              ),
 
-                  ,"list_iterator_"=list(
+              "list_iterator_"=list(
                    signature(x = "list", g = "function" ),
                    'Function fun(g) ;
-		    List input(x) ;
-		    List output( input.size() ) ;
-		    std::transform( input.begin(), input.end(), output.begin(), fun ) ;
-		    output.names() = input.names() ;
-		    return output ; ')
+				    List input(x) ;
+				    List output( input.size() ) ;
+				    std::transform( input.begin(), input.end(), output.begin(), fun ) ;
+				    output.names() = input.names() ;
+				    return output ; '
+              ),
 
-                  ,"list_name_indexing"=list(
+              "list_name_indexing"=list(
                    signature(x = "data.frame"),
                    'List df(x) ;
 	            IntegerVector df_x = df["x"] ;
 	            int res = std::accumulate( df_x.begin(), df_x.end(), 0 ) ;
-	            return wrap(res); ')
+	            return wrap(res); '
+              ),
 
-                  ,"list_push_back"=list(
+              "list_push_back"=list(
                    signature(x = "list"),
                    'List list(x) ;
 	            list.push_back( 10 ) ;
 	            list.push_back( "bar", "foo" ) ;
 	            return list ;
-	           ')
+	           '
+              ),
 
-                  ,"list_push_front"=list(
+              "list_push_front"=list(
                    signature(x = "list"),
                    'List list(x) ;
 	            list.push_front( 10 ) ;
 	            list.push_front( "bar", "foo" ) ;
-	            return list ; ')
+	            return list ; '
+              ),
 
-                  ,"list_erase"=list(
+              "list_erase"=list(
                    signature(x = "list"),
                    'List list(x) ;
 	            list.erase( list.begin() ) ;
-	            return list ; ')
+	            return list ; '
+              ),
 
-                  ,"list_erase_range"=list(
+              "list_erase_range"=list(
                    signature(x = "list"),
 	           'List list(x) ;
 	            list.erase( 0, 1 ) ;
-	            return list ; ')
+	            return list ; '
+              ),
 
-                  ,"list_implicit_push_back"=list(
+              "list_implicit_push_back"=list(
                    signature(),
                    'List list ;
                     list["foo"] = 10 ;
                     list["bar" ] = "foobar" ;
                     return list ;
-                   '), 
-              "list_create_" = list( 
-              	signature(), 
-              	'
-					List output(2); 
+                   '
+              ),
+
+              "list_create_" = list(
+              		signature(),
+              		'
+					List output(2);
 					output[0] = List::create( 10, "foo" ) ;
-					output[1] = List::create( 
-						_["foo"] = 10, 
+					output[1] = List::create(
+						_["foo"] = 10,
 						_["bar"] = true ) ;
 					return output ;
 				'
-              ), 
-              "list_stdcomplex" = list( 
+              ),
+
+              "list_stdcomplex" = list(
               		signature() , '
               			std::vector< std::complex<double> > v_double(10) ;
     					std::vector< std::complex<float> > v_float(10) ;
     					return List::create( _["float"] = v_float, _["double"] = v_double ) ;
     				'
-    			), 
-    			
-    			
-    			
-    			
+              ),
+
               "character_ctor"=list(
                   signature(),
                   'CharacterVector x(10) ;
-	           for( int i=0; i<10; i++) x[i] = "foo" ;
-	           return x ;')
+	          		 for( int i=0; i<10; i++) x[i] = "foo" ;
+			           return x ;'
+              ),
 
-                  ,"character_STRSXP_"=list(
+              "character_STRSXP_"=list(
                    signature(vec = "character" ),
                    'CharacterVector x(vec) ;
 	            std::string st = "" ;
 	            for( int i=0; i<x.size(); i++) {
 		         st += x[i] ;
 	            }
-	            return wrap( st ) ;' )
+	            return wrap( st ) ;'
+              ),
 
-                  ,"character_plusequals"=list(
+              "character_plusequals"=list(
                    signature(),
                    'CharacterVector x(2) ;
 	            x[0] = "foo" ;
 	            x[1] = "bar" ;
 	            x[0] += "bar" ;
 	            x[1] += x[0] ;
-	            return x ;')
+	            return x ;'
+              ),
 
-                  ,"character_matrix_indexing"=list(
+              "character_matrix_indexing"=list(
                    signature(x = "character" ),
                    'CharacterVector m(x) ;
-		    std::string trace;
-		    for( size_t i=0 ; i<4; i++){
-		        trace += m(i,i) ;
-		    }
-		    return wrap( trace ) ;')
+				    std::string trace;
+				    for( size_t i=0 ; i<4; i++){
+				        trace += m(i,i) ;
+				    }
+				    return wrap( trace ) ;'
+              ),
 
-                  ,"character_matrix_indexing_lhs"=list(
+              "character_matrix_indexing_lhs"=list(
                    signature(x = "integer" ),
                    'CharacterVector m(x) ;
-		    for( size_t i=0 ; i<4; i++){
-		        m(i,i) = "foo" ;
-		    }
-		    return m ;')
+				    for( size_t i=0 ; i<4; i++){
+				        m(i,i) = "foo" ;
+				    }
+				    return m ;'),
 
-                  ,"character_assign1"=list(
+              "character_assign1"=list(
                    signature(),
                    'const char* x[] = { "foo", "bar", "bling", "boom" } ;
-		    CharacterVector y ;
-		    y.assign( x, x+4 ) ;
-		    return y;')
+		    		CharacterVector y ;
+				    y.assign( x, x+4 ) ;
+				    return y;'
+              ),
 
-                  ,"character_assign2"=list(
+              "character_assign2"=list(
                    signature(),
                    'std::vector<std::string> vec(4) ;
-		    vec[0] = "foo";
-		    vec[1] = "bar";
-		    vec[2] = "bling";
-		    vec[3] = "boom" ;
-		    CharacterVector y ;
-		    y.assign( vec.begin(), vec.end() ) ;
-		    return y;')
+				    vec[0] = "foo";
+				    vec[1] = "bar";
+				    vec[2] = "bling";
+				    vec[3] = "boom" ;
+				    CharacterVector y ;
+				    y.assign( vec.begin(), vec.end() ) ;
+				    return y;'
+              ),
 
-                  ,"character_range_ctor1"=list(
+              "character_range_ctor1"=list(
                    signature(),
                    'const char* x[] = { "foo", "bar", "bling", "boom" } ;
-		    CharacterVector y( x, x+4 ) ;
-		    return y;')
+				    CharacterVector y( x, x+4 ) ;
+				    return y;'
+              ),
 
-                  ,"character_range_ctor2"=list(
+              "character_range_ctor2"=list(
                    signature(),
                    'std::vector<std::string> vec(4) ;
-		    vec[0] = "foo";
-		    vec[1] = "bar";
-		    vec[2] = "bling";
-		    vec[3] = "boom" ;
-		    CharacterVector y( vec.begin(), vec.end() ) ;
-		    return y; ')
+				    vec[0] = "foo";
+				    vec[1] = "bar";
+				    vec[2] = "bling";
+				    vec[3] = "boom" ;
+				    CharacterVector y( vec.begin(), vec.end() ) ;
+				    return y; '
+              ),
 
-                  ,"character_dimension_ctor1"=list(
+              "character_dimension_ctor1"=list(
                    signature(),
-                   'return CharacterVector( Dimension( 5 ) ) ;')
+                   'return CharacterVector( Dimension( 5 ) ) ;'
+              ),
 
-                  ,"character_dimension_ctor2"=list(
+              "character_dimension_ctor2"=list(
                    signature(),
-                   'return CharacterVector( Dimension( 5, 5 ) ) ;')
+                   'return CharacterVector( Dimension( 5, 5 ) ) ;'
+              ),
 
-                  ,"character_dimension_ctor3"=list(
+              "character_dimension_ctor3"=list(
                    signature(),
-                   'return CharacterVector( Dimension( 2, 3, 4) ) ;')
+                   'return CharacterVector( Dimension( 2, 3, 4) ) ;'
+              ),
 
-                  ,"character_iterator1"=list(
+              "character_iterator1"=list(
                    signature(x = "character"),
                    'CharacterVector letters(x) ;
-		    std::string res ;
-		    CharacterVector::iterator first = letters.begin() ;
-		    CharacterVector::iterator last = letters.end() ;
-		    while( first != last ){
-		        res += *first ;
-			++first ;
-		    }
-		    return wrap(res) ;' )
+				    std::string res ;
+				    CharacterVector::iterator first = letters.begin() ;
+				    CharacterVector::iterator last = letters.end() ;
+				    while( first != last ){
+				        res += *first ;
+						++first ;
+				    }
+		    		return wrap(res) ;'
+              ),
 
-                  ,"character_iterator2"=list(
+              "character_iterator2"=list(
                    signature(x = "character"),
                    'CharacterVector letters(x) ;
-		    std::string res(std::accumulate(letters.begin(), letters.end(), std::string()));
-		    return wrap(res) ;' )
+		    		std::string res(std::accumulate(letters.begin(), letters.end(), std::string()));
+		    		return wrap(res) ;'
+              ),
 
-                  ,"character_reverse"=list(
+              "character_reverse"=list(
                    signature(x = "character"),
                    'CharacterVector y(x) ;
-		    std::reverse( y.begin(), y.end() ) ;
-		    return y ;')
+		    		std::reverse( y.begin(), y.end() ) ;
+		    		return y ;'
+              ),
 
-                  ,"character_names_indexing"=list(
+              "character_names_indexing"=list(
                    signature(x = "character"),
                    'CharacterVector y(x) ;
-		    std::string foo( y["foo"] ) ;
-		    return wrap(foo) ;')
+		    		std::string foo( y["foo"] ) ;
+		    		return wrap(foo) ;'
+              ),
 
-                  ,"character_comma"=list(
+              "character_comma"=list(
                    signature(),
                    'CharacterVector x(3) ;
-        	    x = "foo", "bar", "bling" ;
-        	    return x ;')
+        	  		x = "foo", "bar", "bling" ;
+        	    	return x ;'
+              ),
 
-                  ,"character_listOf"=list(
+              "character_listOf"=list(
                    signature(l = "list"),
                    'List ll(l);
                     CharacterVector cv1 = ll["foo"];
                     CharacterVector cv2 = ll["bar"];
                     std::string rv1 = std::string(cv1[0]) + cv1[1] + cv1[2];
                     std::string rv2 = std::string(cv2[0]) + cv2[1] + cv2[2];
-                    return List::create(_["foo"] = rv1, _["bar"] = rv2); ')
+                    return List::create(_["foo"] = rv1, _["bar"] = rv2); '
+              ),
 
-                  ,"character_find_"=list(
+              "character_find_"=list(
                    signature(x = "character"),
                    'CharacterVector y(x) ;
-	            CharacterVector::iterator it = std::find( y.begin(), y.end(), "foo" ) ;
-	            return wrap( std::distance( y.begin(), it )); '
-	            
-	            ), "character_create_" = list( 
-	            	signature(), 
+	          		CharacterVector::iterator it = std::find( y.begin(), y.end(), "foo" ) ;
+	            	return wrap( std::distance( y.begin(), it )); '
+
+              ),
+
+              "character_create_" = list(
+	            	signature(),
 	            	'
-						List output(2); 
+						List output(2);
 						output[0] = CharacterVector::create( "foo", "bar" ) ;
-						output[1] = CharacterVector::create( 
-							_["foo"] = "bar", 
+						output[1] = CharacterVector::create(
+							_["foo"] = "bar",
 							_["bar"] = "foo"
 							) ;
 						return output ;
 					'
-	            ), "complex_binary_sugar" = list( 
-	            	signature( x = "complex", y = "complex" ), 
+              ),
+
+              "complex_binary_sugar" = list(
+	            	signature( x = "complex", y = "complex" ),
 	            	'
 	            		ComplexVector xx(x), yy(y) ;
-	            		return List::create( 
-	            			_["+"] = xx + yy, 
-	            			_["-"] = xx - yy, 
-	            			_["*"] = xx * yy, 
+	            		return List::create(
+	            			_["+"] = xx + yy,
+	            			_["-"] = xx - yy,
+	            			_["*"] = xx * yy,
 	            			_["/"] = xx / yy
 	            		) ;
-	            	
+
 	            	'
-	            ), 
-	            "List_extract" = list( 
-	                signature( x = "list" ), 
+              ),
+
+              "List_extract" = list(
+	                signature( x = "list" ),
 	                '
 	                    List input(x) ;
 	                    bool a = input[0] ;
 	                    int b = input[1] ;
 	                    return List::create(a, b) ;
 	                '
-	            ), 
-	            "factors" = list( 
-	                signature( x = "factor" ), 
+              ),
+
+	          "factors" = list(
+	                signature( x = "factor" ),
 	                '
 	                    StringVector s(x) ;
-	                    return s; 
+	                    return s;
 	                '
-	            )
-                  
-        )
+	          ),
 
-        if (Rcpp:::capabilities()[["initializer lists"]]) {
-        	g <- list( 
-        		"raw_initializer_list"=list(
-        			signature(), 
+	          "IntegerVector_int_init" = list(
+	                signature(),
+	                '
+	                    IntegerVector x(2,4) ;
+	                    return x ;
+	                '
+	          ),
+
+              "containsElementNamed" = list(
+                	signature(ls="list", ns="character"),
+                	'
+                	    List l(ls);
+                            CharacterVector n(ns);
+
+			    return wrap(l.containsElementNamed(n[0]));
+	                '
+              )
+          )
+
+    if (Rcpp:::capabilities()[["initializer lists"]]) {
+        g <- list(
+                  "raw_initializer_list"=list(
+        			signature(),
         			'
 					RawVector x = {0,1,2,3} ;
 					for( int i=0; i<x.size(); i++) x[i] = x[i]*2 ;
 					return x ;
 					'
-        		), 
-        		"complex_initializer_list" = list( 
-        			signature(), 
+                  ),
+
+                  "complex_initializer_list" = list(
+        			signature(),
         			'
 					Rcomplex c1 ; c1.r = c1.i = 0.0 ;
 					Rcomplex c2 ; c2.r = c2.i = 1.0 ;
 					ComplexVector x = { c1, c2 } ;
 					return x ;
 					'
-        		), 
-        		"integer_initializer_list"=list(
+                  ),
+
+
+                  "integer_initializer_list"=list(
                   	signature(),
                   	'
                   		IntegerVector x = {0,1,2,3} ;
 		   				for( int i=0; i<x.size(); i++) x[i] = x[i]*2 ;
 		   				return x ;
 		   			'
-		   		), 
-		   		
-		   		"numeric_initlist" = list( 
-        			signature(), 
+                  ),
+
+                  "numeric_initlist" = list(
+        			signature(),
         			'
 						NumericVector x = {0.0,1.0,2.0,3.0} ;
 						for( int i=0; i<x.size(); i++) x[i] = x[i]*2 ;
 						return x ;
 					'
-        		), 
-        		
-        		"list_initializer_list"=list(
-                  signature(),
-                  'SEXP x0 = PROTECT( Rf_ScalarInteger( 0 ) ) ;
+                  ),
+
+                  "list_initializer_list"=list(
+                  	signature(),
+                  	'SEXP x0 = PROTECT( Rf_ScalarInteger( 0 ) ) ;
 		   			SEXP x1 = PROTECT( Rf_ScalarInteger( 1 ) ) ;
 		   			SEXP x2 = PROTECT( Rf_ScalarInteger( 2 ) ) ;
 		   			List x = { x0, x1, x2} ;
 		   			UNPROTECT(3) ;
-		   			return x ;'), 
-		   			
-		   		"character_initializer_list"=list(
-                  signature(),
-                  'CharacterVector x = {"foo", "bar"} ;
-                  return x ;')
+		   			return x ;'
+                  ),
 
-                  
-        	)     
-        	f <- c(f,g)
-        }
-        f
-    
+
+                  "character_initializer_list"=list(
+                  	signature(),
+                  	'CharacterVector x = {"foo", "bar"} ;
+                  	return x ;'
+                  )
+
+
+                  )
+        f <- c(f,g)
+    }
+    f
 }
 
 includes <- function(){
 "
     inline double square( double x){ return x*x; }
-"    
+"
 }
 
 cxxargs <- function(){
@@ -681,9 +774,9 @@ cxxargs <- function(){
 .setUp <- function() {
     tests <- ".rcpp.Vector"
     if( ! exists( tests, globalenv() )) {
-        fun <- Rcpp:::compile_unit_tests( 
-            definitions(), 
-            includes = includes(), 
+        fun <- Rcpp:::compile_unit_tests(
+            definitions(),
+            includes = includes(),
             cxxargs = cxxargs()
         )
         assign( tests, fun, globalenv() )
@@ -712,7 +805,7 @@ test.ExpressionVector <- function(){
 	ex <- parse( text = "rnorm; rnorm(10)" )
 	# get rid of the srcref stuff so that we can compare
 	# more easily
-	attributes(ex) <- NULL 
+	attributes(ex) <- NULL
 	checkEquals( funx(),  ex , msg = "ExpressionVector" )
 }
 
@@ -746,20 +839,20 @@ test.ExpressionVector.eval.env <- function(){
 	e[["x"]] <- sample(1:10)
 	checkEquals( funx(e), 1:10, msg = "ExpressionVector::eval in specific environment" )
 }
-         
+
 test.ComplexVector <- function(){
 	funx <- .rcpp.Vector$complex_
 	checkEquals( funx(), 0:9*(1+1i), msg = "ComplexVector" )
 }
 test.ComplexVector.CPLXSXP <- function(){
 	funx <- .rcpp.Vector$complex_CPLXSXP
-     vv = (0:9)*(1+1i) ## not working - funx changes its argument 
+     vv = (0:9)*(1+1i) ## not working - funx changes its argument
 	#checkEquals( funx(vv), 2*vv, msg = "ComplexVector( CPLXSXP) " )
 	checkEquals( funx((0:9)*(1+1i)), 2*(0:9)*(1+1i), msg = "ComplexVector( CPLXSXP) " )
 }
 test.ComplexVector.INTSXP <- function(){
 	funx <- .rcpp.Vector$complex_INTSXP
-    vv <- 0L:9L  
+    vv <- 0L:9L
 	checkEquals( funx(vv), (2+0i)*vv, msg = "ComplexVector( INTSXP) " )
 }
 test.ComplexVector.REALSXP <- function(){
@@ -925,7 +1018,7 @@ test.IntegerVector.create.zero <- function( ){
 
 test.IntegerVector.create <- function(){
     fun <- .rcpp.Vector$integer_create_
-	checkEquals( fun(), list( c( 10L, 20L) , c(foo = 20L, bar = 30L) ), 
+	checkEquals( fun(), list( c( 10L, 20L) , c(foo = 20L, bar = 30L) ),
 		msg = "IntegerVector::create" )
 }
 
@@ -936,7 +1029,7 @@ test.IntegerVector.clone <- function(){
 	checkEquals( x, 1:10, msg = "clone" )
 	checkEquals( y, 10:1, msg = "clone" )
 }
-          
+
 
 
 
@@ -960,14 +1053,14 @@ if( Rcpp:::capabilities()[["initializer lists"]] ){
 
 test.NumericVector.import <- function(){
 	funx <- .rcpp.Vector$numeric_import
-	checkEquals( funx(), 0:9, msg = "IntegerVector::import" ) 
+	checkEquals( funx(), 0:9, msg = "IntegerVector::import" )
 }
 
 test.NumericVector.import.transform <- function(){
 	funx <- .rcpp.Vector$numeric_importtransform
 	checkEquals( funx(), (0:9)^2, msg = "NumericVector::import_transform" )
 }
-         
+
 
 
 
@@ -1094,18 +1187,18 @@ test.List.implicit.push.back <- function(){
 
 test.List.create <- function(){
 	fun <- .rcpp.Vector$list_create_
-    checkEquals( fun(), list( list( 10L, "foo" ), list(foo = 10L, bar =  TRUE ) ), 
+    checkEquals( fun(), list( list( 10L, "foo" ), list(foo = 10L, bar =  TRUE ) ),
 		msg = "List::create" )
 }
 
 test.List.stdcomplex <- function(){
 	fun <- .rcpp.Vector$list_stdcomplex
-    checkEquals( 
-		fun(), 
-		list( float = rep(0+0i, 10), double = rep(0+0i, 10) ), 
+    checkEquals(
+		fun(),
+		list( float = rep(0+0i, 10), double = rep(0+0i, 10) ),
 		msg = "range wrap over std::complex" )
 }
-           
+
 
 
 
@@ -1222,30 +1315,30 @@ test.CharacterVector.find <- function(){
     fun <- .rcpp.Vector$character_find_
     checkEquals( fun( c("bar", "foo", "bob") ), 1L, msg = "support for std::find in CharacterVector" )
 }
-    
+
 test.CharacterVector.create <- function(){
 	fun <- .rcpp.Vector$character_create_
-    checkEquals( fun(), list( c( "foo", "bar" ), c(foo = "bar", bar = "foo" ) ), 
+    checkEquals( fun(), list( c( "foo", "bar" ), c(foo = "bar", bar = "foo" ) ),
 	 	msg = "CharacterVector::create" )
 }
 
 test.ComplexVector.binary.operators <- function(){
-	fun <- .rcpp.Vector$complex_binary_sugar
+    fun <- .rcpp.Vector$complex_binary_sugar
     x <- (1+1i) * 1:10
     y <- (2-3i) * 1:10
-    
-	checkEquals( 
-		fun(x, y), 
-		list( 
-			"+" = x + y, 
-			"-" = x - y, 
+
+    checkEquals(
+		fun(x, y),
+		list(
+			"+" = x + y,
+			"-" = x - y,
 			"*" = x * y,
 			"/" = x / y
 		), msg = "complex binary operators" )
 }
 
 test.ComplexVector.binary.operators <- function(){
-	fun <- .rcpp.Vector$List_extract
+    fun <- .rcpp.Vector$List_extract
     checkEquals( fun(list(TRUE, 4)), list(TRUE, 4L) )
     checkEquals( fun(list(FALSE, -4L)), list(FALSE,-4L) )
 }
@@ -1256,3 +1349,20 @@ test.factors <- function(){
     y <- fun(x)
     checkEquals( y, as.character(x) )
 }
+
+test.IntegerVector_int_init <- function(){
+    fun <-    .rcpp.Vector$IntegerVector_int_init
+    checkEquals( fun(), c(4L,4L), msg = "IntegerVector int init regression test" )
+}
+
+test.containsElementNamed <- function() {
+    fun <- .rcpp.Vector$containsElementNamed
+
+    x <- list( foo = 2, bla = 1:10 )
+
+    checkEquals(fun(x, "foo"), TRUE, msg = "containsElementNamed with element")
+    checkEquals(fun(x, "bar"), FALSE, msg = "containsElementNamed without element")
+    checkEquals(fun(x, ""), FALSE, msg = "containsElementNamed with empty element")
+}
+
+}
