@@ -2,7 +2,7 @@
 //
 // Function.cpp: Rcpp R/C++ interface class library -- functions
 //
-// Copyright (C) 2010 - 2011 Dirk Eddelbuettel and Romain Francois
+// Copyright (C) 2010 - 2012  Dirk Eddelbuettel and Romain Francois
 //
 // This file is part of Rcpp.
 //
@@ -23,7 +23,7 @@
 
 namespace Rcpp {
 	
-    Function::Function( SEXP x = R_NilValue ) : RObject( ){
+    Function::Function(SEXP x) : RObject( ){
         switch( TYPEOF(x) ){
         case CLOSXP:
         case SPECIALSXP:
